
* This code starts from DADS Postes files in Stata format, select variables, do some cleaning, and save data in Stata format.

* create folder for cleaned data
cd "${dir}/rawdata/dads_postes"
capture mkdir cleaned

cd "${dir}"


*** Construct annual worker-level DADS files 1994-2006

*** 1994-1996
forvalues t = 1994(1)1996 {
* append all regions
clear
gen r = ""
foreach r in 11 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 {
append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'"
replace r = "`r'" if r==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if reg==r
drop r
* until 1996: 10-digit siren and 6-digit nic
replace siren = substr(siren,2,9)
replace nic = substr(nic,2,5)
rename cipdz ce
rename eqtc etp
foreach x in brut brut_1 {
replace `x' = `x'/6.55957
}
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen
save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}

*** 1997-2001
forvalues t = 1997(1)2001 {
* append all regions
clear
gen r = ""
foreach r in 11 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 {
append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'"
replace r = "`r'" if r==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if reg==r
drop r
* 1997-2001: 9-digit siren, called sirenn
rename sirenn siren
rename nicc nic
rename cipdz ce
rename eqtc etp
foreach x in brut brut_1{
replace `x' = `x'/6.55957 if `t' <=1999
}
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen
save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}

*** 2002-2008
forvalues t = 2002(1)2008 {
* append all regions
clear
gen r = ""
foreach r in 11 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 {
append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
replace r = "`r'" if r==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if regt==r
drop r

rename s_net netnet // net wage
rename s_brut brut
rename cs cs2 // 2-digit occupation
rename pcs pcs4
rename cpfd ce
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen
save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}

*** 2009-2011
foreach t in 2009 2010 2011 {
* append all regions
clear
gen r = ""
* list of files change from year to year
if `t'==2009 {
	foreach r in 11aa 11bb 11cc 11dd {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	}
	replace r = "11" if r==""
	foreach r in 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	replace r = "`r'" if r==""
	}
}
if `t'==2010 {
	foreach r in 11aa 11bb 11cc 11dd {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	}
	replace r = "11" if r==""
	foreach r in 82a 82b {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	}
	replace r = "82" if r==""
	foreach r in 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 83 91 93 94 97 99 {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	replace r = "`r'" if r==""
	}
}
if `t'==2011 {
	foreach r in 11 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 {
	append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
	replace r = "`r'" if r==""
	}
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if regt==r
drop r

rename s_net netnet // net wage
rename s_brut brut
rename pcs pcs4
rename cpfd ce
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen
save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}

*** 2012-2013
forvalues t = 2012(1)2013 {
* append all regions
clear
gen r = ""
foreach r in 21 22 23 24 25 26 31 41 42 43 52 53 54 72 73 74 82 83 91 93 94 97 99 { // all regions except ile de france
append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
replace r = "`r'" if r==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if regt==r
drop r

save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace

* append all ile-de-france departements
clear
gen d = ""
foreach d in 75 77 78 91 92 93 94 95 {
append using "rawdata/dads_postes/raw/dads_postes_`t'_`d'idf.dta"
replace d = "`d'" if d==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if dept==d
drop d

append using "rawdata/dads_postes/cleaned/dads_postes_`t'"

rename s_net netnet // net wage
rename s_brut brut
rename pcs pcs4
rename cpfd ce
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen

save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}

*** 2014-2015
forvalues t = 2014(1)2015 {
* append all regions
clear
gen r = ""
foreach r in 24 27 28 32 44 52 53 75 76 84 93 94 97 99 { // all regions except ile de france
append using "rawdata/dads_postes/raw/dads_postes_`t'_`r'.dta"
replace r = "`r'" if r==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if regt==r
drop r

save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace

* append all ile-de-france departements
clear
gen d = ""
foreach d in 75 77 78 91 92 93 94 95 {
append using "rawdata/dads_postes/raw/dads_postes_`t'_`d'idf.dta"
replace d = "`d'" if d==""
}
* dads file for a given region includes a job spell if either the establishment is located in the region or the individual lives in the region -> keep only if establishment region = file region to drop duplicates
keep if dept==d
drop d

append using "rawdata/dads_postes/cleaned/dads_postes_`t'"

rename s_net netnet // net wage
rename s_brut brut
rename pcs pcs4
rename cpfd ce
rename siren sir
merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen

save "rawdata/dads_postes/cleaned/dads_postes_`t'", replace
}
