
/*
This code extracts firm register data in SAS format, select variables, do some cleaning, and save data in Stata format.
*/

cd "${dir}"


/*------------------------------------------------------------------------------

Step 1: Save raw data in Stata format

------------------------------------------------------------------------------*/

* create directory to store raw data in stata format
cd "${dir}/rawdata"
capture mkdir ree_stock
cd "${dir}/rawdata/ree_stock"
capture mkdir raw
cd "${dir}"

* for each year, open sas file, select variables, and store it in stata format

*** 1993-1999

forvalues year = 1993(1)1999 {

* open SAS file
cd "${rawdatadir}\REE_Stocks Entreprises et Etablissements_`year'"
if `year'==1993 {
	import sas SIRET APEN CJ  using "stojan93.sas7bdat", clear
}
if `year'>=1994 & `year'<=1999 {
	local yr = `year'-1900
	import sas SIRET APEN CJ  using "STOJAN`yr'.sas7bdat", clear
}

* siren number (firm identified) = first 9 digits of siret number (14-digit establisement identifier)
gen siren = substr(SIRET,1,9)
drop SIRET

* sector
/* !!! Industry classification is NAF 1993 !!! */
rename APEN sec

* legal status
rename CJ cj

* data is at establishment level --> keep 1 obs per firm (sec and cj are constant within firms)
bys siren sec cj: keep if _n==1
duplicates report siren sec

* save in Stata format
cd "${dir}/rawdata/ree_stock/raw"
save "firmstock_`year'", replace

}

*** 2000-2008

* for each year, open sas file and store it in stata format
forvalues year = 2000(1)2008 {

* open SAS file
local yr = `year'-2000
cd "${rawdatadir}\REE_Stocks Entreprises_`year'"
import sas SIREN APEN CJ using "STENT0`yr'.sas7bdat", clear

* siren number
rename SIREN siren

* sector
rename APEN sec

* legal status
rename CJ cj

* data is now at siren level
duplicates report siren

* save in Stata format
cd "${dir}/rawdata/ree_stock/raw"
save "firmstock_`year'", replace

}



/*------------------------------------------------------------------------------

Step 2: Create unique Stata file

------------------------------------------------------------------------------*/

* create directory to store cleaned data
cd "${dir}/rawdata/ree_stock"
capture mkdir cleaned
cd "${dir}"

* append all years
clear
gen year = .
forvalues yr = 1993(1)2008 {
append using "${dir}/rawdata/ree_stock/raw/firmstock_`yr'"
replace year = `yr' if year==.
}

* save
rename siren sir
save "${dir}/rawdata/ree_stock/cleaned/firmstock", replace
