

cd "${dir}"


**********  CREATE MAPPINGS   **********
{

*** Define ICT for NAF rev.2, 2008 using mapping from NAF rev.1, 2003
{
* use 2008 as both classifications are reported
use sir nninouv an apet apet2 using "rawdata/dads_panel/dads_panel_2015", clear
keep if an==2008
keep if apet~="" & apet2~=""

* ICT definition in NAF rev.1, 2003
gen ict = inlist(substr(apet,1,2),"72") | inlist(substr(apet,1,3),"300","321","322","323","332","333","642") | inlist(apet,"313Z","516G","518G","518J","713E") if apet~=""

* at sector level: average by NAF rev.2, 2008
preserve
collapse (mean) ict_naf2008=ict, by(apet2)
drop if ict_naf2008==.
replace ict_naf2008 = ict_naf2008>=0.5
save "output/ict_naf2008", replace
restore

* at firm level
preserve
collapse (mean) ict_sir2008=ict, by(sir)
drop if ict_sir2008==.
replace ict_sir2008 = ict_sir2008>=0.5
save "output/ict_sir2008", replace
restore

* firm/worker level
collapse (max) ict_nni2008=ict, by(sir nni)
drop if ict_nni2008==.
save "output/ict_nni2008", replace

}
*


*** Define broad NAF2003 industries for NAF rev.2, 2008 using mapping from NAF rev.1, 2003
{
* use 2008 as both classifications are reported
use an apet apet2 using "rawdata/dads_panel/dads_panel_2015", clear
keep if an==2008
keep if apet~="" & apet2~=""

* broad ind in NAF 2003
gen sec = real(substr(apet,1,2)) if apet~=""
gen broadind_naf2003 = "Agri" if sec>=1 & sec<=5
replace broadind_naf2003 = "Mining" if sec>=10 & sec<=14
replace broadind_naf2003 = "Manuf" if sec>=15 & sec<=37
replace broadind_naf2003 = "Util" if sec>=40 & sec<=41
replace broadind_naf2003 = "Construc" if sec==45
replace broadind_naf2003 = "Retail" if sec>=50 & sec<=52
replace broadind_naf2003 = "Hotel/Resto" if sec==55
replace broadind_naf2003 = "Transport" if sec>=60 & sec<=63
replace broadind_naf2003 = "Telecom" if sec==64
replace broadind_naf2003 = "FIRE" if sec>=65 & sec<=70
replace broadind_naf2003 = "Service" if sec>=71 & sec<=74
replace broadind_naf2003 = "Public" if sec==75
replace broadind_naf2003 = "Educ" if sec==80
replace broadind_naf2003 = "Health" if sec==85
replace broadind_naf2003 = "Soc/Cultu" if sec>=90 & sec<=93
drop if broadind_naf2003=="" // 7 obs

* collapse by NAF rev.2, 2008
gen n = 1
collapse (sum) n, by(broadind_naf2003 apet2)

* assign broadind_naf2003 with larger weight (>.9 for 99% of obs)
egen totn = sum(n), by(apet2)
gen w = n/totn
egen maxw = max(w), by(apet2)
sum maxw [aw=totn], d
gsort apet2 -w broadind_naf2003
by apet2: keep if _n==1
keep apet2 broadind_naf2003
label var broadind_naf2003 "Broad NAF2003 industries assigned to fine NAF2008 industries"
save "output/naf2008_to_broadind_naf2003_naf2008", replace
}
*


*** Mappings NAF rev.1, 2003 to NAF rev.2, 2008: at 2-digit, 3-digit, 4-digit levels
{

* Firms with NAF2 sector from Fare 2009
use sir ape_diff redi_r310 using "rawdata/ficus_fare/raw/fare2009", clear
rename ape_diff naf 
rename redi_r310 catotal  
keep if catotal>0 & catotal<.
save "output/temp", replace

* Merge with firms with NAF1 sector from Ficus 2007
use siren ape catotal using "rawdata/ficus_fare/raw/ficus2007tab", clear
append using "rawdata/ficus_fare/raw/ficus2007fin", keep(siren ape catotal)
append using "rawdata/ficus_fare/raw/ficus2007apu", keep(siren ape catotal)
drop if inlist(siren,"",".","0","000000000")
sort siren catotal
by siren: keep if _n==_N
merge 1:1 siren using "output/temp", nogen keep(3)
keep if catotal>0 & catotal<.
save "output/temp", replace

* Assign NAF2 to main NAF1 (at 2,3,4 digit)
foreach d in 2 3 4 {
use "output/temp", clear
gen ape`d' = substr(ape,1,`d')
collapse (sum) catotal, by(naf ape`d')
egen totca = sum(catotal), by(naf)
gen w = catotal/totca
gsort naf -w
by naf: keep if _n==1
keep naf ape`d'
* add a few missing naf2
local new = _N+21
set obs `new'
qui replace naf = "0113Z" if _n==_N & naf==""
qui replace naf = "0149Z" if _n==_N-1 & naf==""
qui replace naf = "0161Z" if _n==_N-2 & naf==""
qui replace naf = "0322Z" if _n==_N-3 & naf==""
qui replace naf = "6411Z" if _n==_N-4 & naf==""
qui replace naf = "6491Z" if _n==_N-5 & naf==""
qui replace naf = "6520Z" if _n==_N-6 & naf==""
qui replace naf = "6530Z" if _n==_N-7 & naf==""
qui replace naf = "8411Z" if _n==_N-8 & naf==""
qui replace naf = "8412Z" if _n==_N-9 & naf==""
qui replace naf = "8413Z" if _n==_N-10 & naf==""
qui replace naf = "8422Z" if _n==_N-11 & naf==""
qui replace naf = "8423Z" if _n==_N-12 & naf==""
qui replace naf = "8424Z" if _n==_N-13 & naf==""
qui replace naf = "8425Z" if _n==_N-14 & naf==""
qui replace naf = "8430A" if _n==_N-15 & naf==""
qui replace naf = "8430B" if _n==_N-16 & naf==""
qui replace naf = "8430C" if _n==_N-17 & naf==""
qui replace naf = "8510Z" if _n==_N-18 & naf==""
qui replace naf = "8730B" if _n==_N-19 & naf==""
qui replace naf = "9900Z" if _n==_N-20 & naf==""
qui replace ape`d'=substr("011A",1,`d') if naf == "0113Z"
qui replace ape`d'=substr("012J",1,`d') if naf == "0149Z"
qui replace ape`d'=substr("011A",1,`d') if naf == "0161Z"
qui replace ape`d'=substr("050C",1,`d') if naf == "0322Z"
qui replace ape`d'=substr("651A",1,`d') if naf == "6411Z"
qui replace ape`d'=substr("652A",1,`d') if naf == "6491Z"
qui replace ape`d'=substr("660F",1,`d') if naf == "6520Z"
qui replace ape`d'=substr("660C",1,`d') if naf == "6530Z"
qui replace ape`d'=substr("751A",1,`d') if naf == "8411Z"
qui replace ape`d'=substr("751C",1,`d') if naf == "8412Z"
qui replace ape`d'=substr("751E",1,`d') if naf == "8413Z"
qui replace ape`d'=substr("752C",1,`d') if naf == "8422Z"
qui replace ape`d'=substr("752E",1,`d') if naf == "8423Z"
qui replace ape`d'=substr("752G",1,`d') if naf == "8424Z"
qui replace ape`d'=substr("752J",1,`d') if naf == "8425Z"
qui replace ape`d'=substr("753A",1,`d') if naf == "8430A"
qui replace ape`d'=substr("753B",1,`d') if naf == "8430B"
qui replace ape`d'=substr("753C",1,`d') if naf == "8430C"
qui replace ape`d'=substr("801Z",1,`d') if naf == "8510Z"
qui replace ape`d'=substr("853C",1,`d') if naf == "8730B"
qui replace ape`d'=substr("9900",1,`d') if naf == "9900Z"
save "output/naf2_naf1rev1_`d'digit", replace
}

}
*

}
*


**********   DADS PANEL   **********
{

*** DADS panel: all job spells at worker-siren-year level
{

* open dads
use comt pan25 pannouv tain ptt depnai ce contrat_travail nni* sir nic4 ///
an regt dept cs2 apet apet2 netnet sn sb nbheur dp debremu finremu annai sx entpan using "rawdata/dads_panel/dads_panel_2015", clear
rename an year

* labels
label var year "Year"
label var sir "Siren"
label var nninouv "Individual"
label var dept "Departement de travail"
label var regt "region de travail"
label var cs2 "CS, missing iff sir==ETAT"
label var apet "NAF1993 until 2002, NAF2003rev1 2003-2008"
label var nbheur "Hours paid"
label var netnet "Net salary"
label var dp "Duree de paie en jours (entre 1 et 360)"
label var debremu "Date de debut de remuneration (entre 1 et 360)"
label var finremu "Date de fin de remuneration (entre 1 et 360)"
label var annai "Annee de naissance"
label var sx "Sex"
label var entpan "Entry year in panel"

rename nic4 nic 
* Drop nir fictif (impossible to identify them in a panel according to documentation)
drop if nnifict=="1"
drop nnifict nnihc // nnihc individual not born in october but added to reach 1/25 sample rate

*** Drop observations before 1985 (won't use it anyway)
drop if year<1985

*** Drop unemployed (appears only after 2008)
drop if ce=="A"

*** keep people in the 1/25 panel (to avoid addition of workers born in odd-numbered years to the panel in 2002)
keep if pan25=="1"

* a few obs with missing or time-varying sex: drop them
destring sx, replace
egen mean_sx = mean(sx), by(nni)
drop if mean_sx~=0 & mean_sx~=1
replace sx = mean_sx
drop mean_sx

gen hourperweek = ceil(nbheur/dp*(360/52))

* define ICT sectors
* in NAF rev.1, 2003 (1993-2008)
gen sec4 = apet
gen sec3 = substr(apet,1,3)
gen sec2 = substr(apet,1,2)
foreach x in ict ict_manuf ict_who ict_tel ict_ser {
gen `x' = 0 if apet~="" & year>=1993
}
replace ict_manuf = 1 if sec3=="300" | sec4=="313Z" | inlist(sec3,"321","322","323","332","333")
replace ict_who = 1 if inlist(sec4,"516G","518G","518J")
replace ict_tel = 1 if sec3=="642"
replace ict_ser = 1 if sec2=="72" | sec4=="713E"
replace ict = ict_manuf+ict_who+ict_tel+ict_ser
drop sec4 sec3 sec2 ict_manuf ict_who ict_tel ict_ser
* use mapping with NAF rev.2, 2008 to define ICT after 2008
* first merge on worker/firm, if worker still in same firm as in 2008
merge m:1 sir nni using "output/ict_nni2008", keep(1 3) nogen
replace ict = ict_nni2008 if ict==. & year>=2008
drop ict_nni2008
* then merge on firm, if firm was already there in 2008
merge m:1 sir using "output/ict_sir2008", keep(1 3) nogen
replace ict = ict_sir2008 if ict==. & year>=2008
drop ict_sir2008
* and finally merge on apet2
merge m:1 apet2 using "output/ict_naf2008", keep(1 3) nogen
replace ict = ict_naf2008 if ict==. & year>=2008
drop ict_naf2008

save "output/panel2015_01", replace

}
*

*** DADS panel: full-time job spells
{

use "output/panel2015_01", clear

* dummy full-time
gen full_dads = ce=="C"

* monthly gros wage, defined only for full time jobs
gen wage = sb/dp*30 if full_dads==1

* clean low-wage obs (sometimes below minimum wage)
* LeMinez and Roux drop observations with wage < 40% SMIC net)
* smic brut from insee website
gen smic_brut = .
replace smic_brut = 4860/6.56 if year==1988
replace smic_brut = 4961/6.56 if year==1989
replace smic_brut = 5156/6.56 if year==1990
replace smic_brut = 5519/6.56 if year==1991
replace smic_brut = 5629/6.56 if year==1992
replace smic_brut = 5886/6.56 if year==1993
replace smic_brut = 6009/6.56 if year==1994
replace smic_brut = 6249/6.56 if year==1995
replace smic_brut = 6374/6.56 if year==1996
replace smic_brut = 6663/6.56 if year==1997
replace smic_brut = 6797/6.56 if year==1998
replace smic_brut = 6881/6.56 if year==1999
replace smic_brut = 7101/6.56 if year==2000
replace smic_brut = 1127 if year==2001
replace smic_brut = 1154 if year==2002
replace smic_brut = 1215 if year==2003
replace smic_brut = 1286 if year==2004
replace smic_brut = 1217 if year==2005
replace smic_brut = 1254 if year==2006
replace smic_brut = 1280 if year==2007
replace smic_brut = 1321 if year==2008
replace smic_brut = 1337 if year==2009
replace smic_brut = 1343 if year==2010
replace smic_brut = 1365 if year==2011
replace smic_brut = 1398 if year==2012
replace smic_brut = 1430 if year==2013
replace smic_brut = 1445 if year==2014
replace smic_brut = 1457 if year==2015
replace smic_brut = 1466 if year==2016
replace smic_brut = 1480 if year==2017
replace smic_brut = 1498 if year==2018
* drop if wage < 60% SMIC brut
replace wage = . if wage<.6*smic_brut
drop smic_brut

* drop part-time & job spells shorter than 6 months
keep if full_dads==1 & hourperweek >= 30
keep if dp>=180

* drop if wage not well defined (below minimum wage)
drop if wage==.
gen logwage = log(wage)

* when worker has several jobs in same year (only 1% of obs since we have already dropped job spells shorter than 6 months), keep the one the with highest wage (to simplify data structure)
sort nni year wage dp cs2 sir
by nni year: keep if _n==_N
sort nni year

* broad industries: NAF 2003
capture drop sec
gen sec = real(substr(apet,1,2)) if apet~="" & year>=1993
gen broadind = "Agri" if sec>=1 & sec<=5
replace broadind = "Mining" if sec>=10 & sec<=14
replace broadind = "Manuf" if sec>=15 & sec<=37
replace broadind = "Util" if sec>=40 & sec<=41
replace broadind = "Construc" if sec==45
replace broadind = "Retail" if sec>=50 & sec<=52
replace broadind = "Hotel/Resto" if sec==55
replace broadind = "Transport" if sec>=60 & sec<=63
replace broadind = "Telecom" if sec==64
replace broadind = "FIRE" if sec>=65 & sec<=70
replace broadind = "Service" if sec>=71 & sec<=74
replace broadind = "Public" if sec==75
replace broadind = "Educ" if sec==80
replace broadind = "Health" if sec==85
replace broadind = "Soc/Cultu" if sec>=90 & sec<=93
replace broadind = "Public" if sir=="ETAT" & broadind=="" & year>=1993
drop sec

* broad industries: NAF2008
merge m:1 apet2 using "output/naf2008_to_broadind_naf2003_naf2008", keep(1 3) nogen
replace broadind = broadind_naf2003 if broadind==""
drop broadind_naf2003
* fill in manually NAF2008 not matched
replace broadind = "Service" if broadind=="" & inlist(substr(apet2,1,2),"74")
replace broadind = "Public" if broadind=="" & inlist(substr(apet2,1,2),"84")
replace broadind = "Educ" if broadind=="" & inlist(substr(apet2,1,2),"85")

save "output/panel2015_full_dads", replace
}
*

*** Construct starting year with employer
{

*For each worker-firm pair, construct first year in which the worker works for the firm.
*We need this variable to identify "joiners" i.e. workers who join in the first years after the firm is created.

use nni sir year using "output/panel2015_01", clear
gsort nni sir year
by nni sir: keep if _n==1
rename year startingyear
save "output/dads_startingyear", replace

}
*

}
*

*** LIST OF FIRMS IN THE DADS PANEL
{

* list of firms that appear in the DADS Panel
use sir using "output/panel2015_full_dads", clear
bysort sir: keep if _n==1
save "output/dads_panel_list_of_sir", replace

}
*


*****   INFLATION
{
	
	clear
	set obs 26
	gen year = 1990+_n
	sum year
	gen euro2000 = 1 if year==2000
	replace euro2000 = 1.148 if year==1991
	replace euro2000 = 1.121 if year==1992
	replace euro2000 = 1.098 if year==1993
	replace euro2000 = 1.08 if year==1994
	replace euro2000 = 1.061 if year==1995
	replace euro2000 = 1.041 if year==1996
	replace euro2000 = 1.028 if year==1997
	replace euro2000 = 1.022 if year==1998
	replace euro2000 = 1.017 if year==1999
	replace euro2000 = .983 if year==2001
	replace euro2000 = .968 if year==2002
	replace euro2000 = .95 if year==2003
	replace euro2000 = .93 if year==2004
	replace euro2000 = .911 if year==2005
	replace euro2000 = .896 if year==2006
	replace euro2000 = .881 if year==2007
	replace euro2000 = .868 if year==2008
	replace euro2000 = .844 if year==2009
	replace euro2000 = .843 if year==2010
	replace euro2000 = .831 if year==2011
	replace euro2000 = .814 if year==2012
	replace euro2000 = .798 if year==2013
	replace euro2000 = .791 if year==2014
	replace euro2000 = .787 if year==2015
	replace euro2000 = .787 if year==2016
	save "${dir}/rawdata/inflation", replace

}
*
