
cd "${dir}"


*****   FIRM-LEVEL VARIABLES
{

*** Number of CEOs and skilled wage bill at firm level: 1994-2015
{

* Create annual files
forvalues t = 1994(1)2015 {
if `t'<=2008 {
	use sir cs2 brut using "rawdata/dads_postes/cleaned/dads_postes_`t'", clear
}
if `t'>=2009 {
	use sir pcs4 brut using "rawdata/dads_postes/cleaned/dads_postes_`t'", clear
	gen cs2 = substr(pcs4,1,2)
}
* number of workers with occupation "pcs=2" ("CEOs")
gen cs2count = substr(cs,1,1)=="2"
* total wage bill for skilled workers
gen skilledwagebill = brut if cs2=="23" | substr(cs2,1,1)=="3"
* collapse at firm level
collapse (sum) cs2count skilledwagebill, by(sir)
save "output/firm_wagebill_`t'", replace
}

* Merge all years
clear
gen year = .
forvalues t = 1994(1)2015 {
append using "output/firm_wagebill_`t'"
replace year = `t' if year==.
}
save "output/firm_wagebill", replace

* Erase annual files
forvalues t = 1994(1)2015 {
erase "output/firm_wagebill_`t'.dta"
}

}	

}


*****   JOB TERMINATION
{

*** Identify next full-time job after a job termination

use nni year sir sb dp debremu finremu ce nbheur apet apet2 using "output/panel2015_01", clear
gen hourperweek = ceil(nbheur/dp*(360/52))
gen fulltime = ce=="C"& hourperweek >= 30
gen wage 	= sb/dp*30 if fulltime==1

* loop on last digit of nni (to work on smaller datasets to speed up the code)
gen lastdigit = substr(nni,length(nni),1)
forvalues digit = 0(1)9 {
preserve
keep if lastdigit=="`digit'"

* identify job termination = same siren does not reappear in next 6 observations
gen deb = year + (min(debremu,360)-1)/360
gen fin = year + (min(finremu,360)-1)/360
drop debremu finremu
sort nni deb
by nni: gen terminated = inlist(sir,sir[_n+1],sir[_n+2],sir[_n+3],sir[_n+4],sir[_n+5],sir[_n+6])==0

* identify next full-time job, looking at the next three obs
gen next_obs = .
forvalues x = 1(1)3 {
by nni: replace next_obs = `x' if terminated==1 & next_obs>`x'-1 & (deb[_n+`x']<. & deb[_n+`x']>fin) & fulltime[_n+`x']==1
}
by nni: gen next_wage = wage[_n+next_obs] // monthly wage of next full-time job
by nni: gen next_dp = dp[_n+next_obs]
by nni: gen next_length = deb[_n+next_obs]-fin // time between termination and next full-time job (in years)
by nni: gen next_apet = apet[_n+next_obs] // sector of next full-time job (pre-2008 classification)
by nni: gen next_apet2 = apet2[_n+next_obs] // sector of next full-time job (post-2008 classification)

* proxies for voluntary job termination
merge m:1 sir year using "output/firm_all_var", keep(1 3) nogen keepusing(gemp1)
rename gemp1 gemp

* job termination leading to the worker changing sector
gen changesec = next_apet~=apet if fulltime==1 & terminated==1 & year<=2014 & apet~="" & next_apet~=""
replace changesec = next_apet2~=apet2 if changesec==. & fulltime==1 & terminated==1 & year<=2014 & apet2~="" & next_apet2~=""

rename gemp term_gemp_ficus
keep nni sir year terminated next_wage next_length term_gemp_ficus changesec

sort nni sir year terminated
by nni sir year: keep if _n==_N
save "output/dads_panel2015_terminated_`digit'", replace
restore
}
* end of loop on first digit of nni

* append all files
clear
forvalues digit = 0(1)9 {
append using "output/dads_panel2015_terminated_`digit'"
}
forvalues digit = 0(1)9 {
erase "output/dads_panel2015_terminated_`digit'.dta"
}

save "output/dads_panel2015_terminated", replace

}


*****   MATCHED DADS-EDP PANEL
{
/*
* construct education at worker level
use nni dip_tot using "rawdata/dads_panel\dads_panel_edp_2015", clear
destring dip_tot, replace force
collapse (max) dip_tot, by(nni)
save "output/dads_edp_2015", replace

*/
}


*****   FINAL PANEL OF FULL-TIME ENTRANTS
{

use "output/panel2015_full_dads", clear
rename nic nic4 // nic in dads postes is in 6 digit but most of the time it contains only 4 real digit

replace ict = 0 if sir=="ETAT"

* define job market entrants (panel already sorted by nni year) for entrants 1991+
sort nni year
by nni: gen year0 = year[1] if year[1]>=1991 & year[1]-annai<=30

* drop non entrants
drop if year0==.

* drop years before 1990
drop if year<1991

* Initial characteristics 
sort nni year
by nni: gen occup0 = cs2[1]
by nni: gen ict0 = ict[1]
by nni: gen apet0 = apet[1]
by nni: gen broadind0 = broadind[1]
by nni: gen regt0 = regt[1]
by nni: gen dept0 = dept[1]
by nni: gen sir0 = sir[1]
by nni: gen nic40 = nic4[1]

* drop if ict at entry not defined: civil servants and a few other missing
drop if ict0==.

* broad occupation at entry
gen broadoccup0 = "high" if substr(occup0,1,1)=="3" | occup0=="23"
replace broadoccup0 = "medium" if substr(occup0,1,1)=="4"
replace broadoccup0 = "low" if inlist(substr(occup0,1,1),"5","6")
drop if broadoccup0==""
drop broadoccup0

* age: keep if older than 20
gen age = year-annai
gen age2 = age^2
gen age0 = year0-annai
gen age0sq = age0^2
keep if age0>=20
drop age age2

* job termination
// current year
merge 1:1 nni sir year using "output/dads_panel2015_terminated", keep(1 3) nogen keepusing(terminated next_wage next_length term_gemp_ficus changesec)
foreach x in terminated next_wage next_length term_gemp_ficus changesec {
rename `x' `x'_cur
}
// next year
replace year = year+1
merge 1:1 nni sir year using "output/dads_panel2015_terminated", keep(1 3) nogen keepusing(terminated next_wage next_length term_gemp_ficus changesec)
replace year = year-1
foreach x in terminated next_wage next_length term_gemp_ficus changesec {
rename `x' `x'_nex
}
// together
gen term = (terminated_cur==1 & terminated_nex~=1) | (terminated_cur~=1 & terminated_nex==1)
foreach x in next_wage next_length term_gemp_ficus changesec {
gen `x' = `x'_cur if terminated_cur==1 & terminated_nex~=1
replace `x' = `x'_cur if terminated_cur~=1 & terminated_nex==1
}
drop *_cur *_nex

/*
* education
merge m:1 nni using "output/dads_edp_2015", keep(1 3) nogen keepusing(dip_tot)
* 1er cycle universitaire
gen univL = dip_tot>=6 if dip_tot<.
* 2e/3e sycle universitaire
gen univM = dip_tot==7 if dip_tot<.
drop dip_tot
*/

* characteristics of initial employer & initial sector
rename sir sir_cur
rename year year_cur
rename apet apet_cur
rename nic4 nic4_cur
rename dept dept_cur
rename sir0 sir
rename year0 year
rename apet0 apet
rename nic40 nic4
rename dept0 dept

merge m:1 apet using "output/sec_stock", keep(1 3) nogen
merge m:1 sir year using "output/gcap", keep(1 3) nogen
merge m:1 sir year using "output/firm_all_var", keep(1 3) nogen keepusing(S Y L Sf5 ebe tot_act tfp yearcrea_ficus yearcrea gemp* gsal*)
rename ebe ebitda0
rename tot_act totass0
rename yearcrea yearcrea0
rename yearcrea_ficus yearcrea0_ficus
merge m:1 sir using "output/lifi", keep(1 3) nogen

rename sir sir0
rename year year0
rename apet apet0
rename nic4 nic40
rename dept dept0
rename sir_cur sir
rename year_cur year
rename apet_cur apet
rename nic4_cur nic4
rename dept_cur dept

gen firmage0 = year0-yearcrea0_ficus
gen startup0 = yearcrea0<. & (yearcrea0>=year0-2) & (yearcrea0<=year0)

* characteristics of current employer
merge m:1 sir year using "output/firm_all_var", nogen keep(1 3) keepusing(ebe resultat div)
merge m:1 sir using "rawdata/ree_creation/cleaned/creation", keep(1 3) nogen
merge m:1 sir year using "output/firm_wagebill", keep(1 3) nogen

* Define cohort
gen coh = "pre" if year0>=1994 & year0<=1996
replace coh = "boom" if year0>=1998 & year0<=2001
replace coh = "post" if year0>=2003 & year0<=2005

*** Broad sector at entry

gen sec = real(substr(apet0,1,2)) if year0<2008
* 32-sector classification = Insee 31-sector classification in "sous-sections" where we split GA "commerce" into 51 wholesale vs. 50/52 retail
gen naf32 = "AA" if sec>=1 & sec<=2
replace naf32 = "BA" if sec==5
replace naf32 = "CA" if sec>=10 & sec<=12
replace naf32 = "CB" if sec>=13 & sec<=14
replace naf32 = "DA" if sec>=15 & sec<=16
replace naf32 = "DB" if sec>=17 & sec<=18
replace naf32 = "DC" if sec==19
replace naf32 = "DD" if sec==20
replace naf32 = "DE" if sec>=21 & sec<=22
replace naf32 = "DF" if sec==23
replace naf32 = "DG" if sec==24
replace naf32 = "DH" if sec==25
replace naf32 = "DI" if sec==26
replace naf32 = "DJ" if sec>=27 & sec<=28
replace naf32 = "DK" if sec==29
replace naf32 = "DL" if sec>=30 & sec<=33
replace naf32 = "DM" if sec>=34 & sec<=35
replace naf32 = "DN" if sec>=36 & sec<=37
replace naf32 = "EA" if sec>=40 & sec<=41
replace naf32 = "FA" if sec==45
replace naf32 = "GA" if sec>=50 & sec<=52
replace naf32 = "51" if sec==51
replace naf32 = "HA" if sec==55
replace naf32 = "IA" if sec>=60 & sec<=64
replace naf32 = "JA" if sec>=65 & sec<=67
replace naf32 = "KA" if sec>=70 & sec<=74
replace naf32 = "LA" if sec==75
replace naf32 = "MA" if sec==80
replace naf32 = "NA" if sec==85
replace naf32 = "OA" if sec>=90 & sec<=93
replace naf32 = "PA" if sec>=95 & sec<=97
replace naf32 = "QA" if sec==99
drop sec

*** Create consistent industry classification througout the sample period
rename apet2 naf	// naf2008 industry classification used after 2008
foreach d in 2 3 4 {	// construct 2-digit, 3-digit and 4-digit classifications
//"apet": naf2003 industry classification used until 2008
gen sec`d' = substr(apet,1,`d')
//"apet2" = "naf": naf2008 industry classification used after 2008
//mapping naf2008 --> naf2003: bring in variable called "ape`d'"
merge m:1 naf using "output/naf2_naf1rev1_`d'digit", keep(1 3) nogen
replace sec`d' = ape`d' if sec`d'==""
}
rename naf apet2

*** Total earnings accounting for stock ownership

foreach var in div resultat ebe {
* when the firm is not matched with Ficus-Fare, earnings is missing -> set to zero
recode `var' .=0
* monthly earnings
replace `var'=(`var')*1000/12 // amounts in Ficus-Fare are yearly and in 1000 euros
}

* Adjustment 1: If worker is CEOs (1-digit CS = 2), add firm's earnings to the wage
* when there are multiple cs=2, add 1/N of the firm's earnings
gen earnings_ceo	= wage
replace earnings_ceo= wage + (max(resultat,0)/cs2count) if substr(cs2,1,1)=="2" & cs2count<. & cs2count>0
replace earnings_ceo= wage + max(resultat,0) if substr(cs2,1,1)=="2" & (cs2count==. | cs2count==0)
replace earnings_ceo= 11*wage if earnings_ceo>11*wage & earnings_ceo<.	// winsorize non-wage earnings at 10 times the wage to account of measurement error

* Adjustment 2: If worker is high-skill (cs=23 or 3x), adjust worker's earnings for stock options
* if the firm is 7 years old of less, attribute 1/3 of earnings to skilled workers who joined within 3 years of firm creation
* add firm's earnings in proportion to share of own wage in total skilled wage bill
merge m:1 nni sir using "output/dads_startingyear", keep(1 3) nogen 	// bring startingyear = year in which the worker started with the firm
gen share 			= (wage*dp/30)/skilledwagebill
replace share 		= 0 if share<0
replace share 		= 1 if share>1 & share<.
recode share 		.=0
gen earnings_all	= wage
replace earnings_all= wage + max(resultat,0)*share*(1/3) ///
	if (year<=yearcrea+7 & yearcrea<.) /// the firm is 7 year old or less
	& (startingyear<=yearcrea+3 & yearcrea<.) /// the worker joined within 3 years of firm creation
	& (substr(cs2,1,2)=="23" | substr(cs2,1,1)=="3") // skilled worker
replace earnings_all= 4*wage if earnings_all>4*wage & earnings_all<.	// winsorize non-wage earnings at 3 times the wage to account for maesurement error

* total earnings
foreach x in ceo all {
gen learnings_`x' = log(earnings_`x') 
}


*** Job termination

* job termination
sort nni year
gen swi_sir = inlist(sir,sir[_n+1],sir[_n+2],sir[_n+3],sir[_n+4],sir[_n+5],sir[_n+6])==0
replace term = swi_sir==1 & term==1
drop swi_sir

* forced termination
gen forced1 = next_wage<wage if term==1 & year<=2014 & next_wage<.
gen forced2 = term_gemp_ficus<0 if term==1 & term_gemp_ficus<.

gegen term_all = max(term==1 & year<=year0+3), by(nni)
gegen term_dwage = max(forced1==1 & year<=year0+3), by(nni)
gegen term_demp = max(forced2==1 & year<=year0+3), by(nni)

* termination leading to a change in sector
gegen termsec_all = max(term==1 & changesec==1 & year<=year0+3), by(nni)
gegen termsec_dwage = max(forced1==1 & changesec==1 & year<=year0+3), by(nni)
gegen termsec_demp = max(forced2==1 & changesec==1 & year<=year0+3), by(nni)

*** Firm characteristics
* size
gen logL = log(L+1)
gen logY = log(Y+1)
gen logK = log(totass0+1)
* labor productivity
gen YL = (Y/(L+1))
replace YL = 0 if YL<0
replace YL = 300 if YL>300 & YL<. //winsorize at roughly 5*IQR above median
* 5-year sales growth
replace S = 0 if S<0
replace Sf5 = 0 if Sf5<0
gen growth5yr	= (Sf5-S)/((Sf5+S)*0.5)
* ROA
gen roa = ebitda0/totass0
replace roa = -.25 if roa<-.25
replace roa = .5 if roa>.5 & roa<.
* margin
gen margin = ebitda0/Y
replace margin = -.5 if margin<-.5
replace margin = 1 if margin>1 & margin<.
* US owned
replace usa = 0 if usa==.
* business group
gen busgrp = businessgroup==1

save "output/entrants2015_fulltime", replace

}


*****   CUMULATIVE EARNINGS
{

* Calculate total earnings across all jobs spells at worker-year level
use nni year sb dp nbheur using "output/panel2015_01", clear
replace dp = -dp if dp<0	// 3 obs
collapse (sum) nbheur sb dp, by(nni year)
keep if year>=1993
replace dp=360 if dp>360 
save "output/earnings", replace

* Start from panel of entrants, and add observation in gap years
use nni year using "output/entrants2015_fulltime", clear

* number of subsequent missing years
sort nni year
by nni: gen b = year[_n+1] - year if _n<_N
by nni: replace b = 2015 - year+1 if _n==_N

* fill in gap years
expand b
drop b
sort nni year
by nni year: replace year = year[1]+_n-1

* merge with total earnings
merge 1:1 nni year using "output/earnings", keep(1 3) nogen
gen earnings 		= sb
replace earnings	= 0 if earnings ==.

* earnings0 = no adjustment
gen earnings0 = earnings

* earnings1: add UB=60% of previous income for 1 year
sort nni year
gen earnings1 = earnings
by nni : replace earnings1 = earnings[_n-1]*0.6 if earnings1==0

* earnings2 = add UB=60% of previous income for 1 year + for 2nd year if previous job spell is at least 2 years
gen earnings2 = earnings
by nni : replace earnings2 = earnings[_n-1]*0.6 if earnings2==0
by nni : replace earnings2 = earnings[_n-2]*0.6 if earnings2==0 & earnings[_n-3]>0

* calculate discounted sum
sort nni year
foreach x in 0 1 2 {
by nni: gen totearnings`x' 	= sum(earnings`x')
by nni: gen pv`x' 			= earnings`x' if _n==1 
by nni: replace pv`x' 		= pv`x'[_n-1] + earnings`x'/1.05^(year-year[1]) if _n>1
}
keep nni year totearnings* pv*
save "output/cumulative_earnings", replace

erase "output/earnings.dta"

}
