
cd "${dir}"

*-------------------------------------------------------------------------------
* FACTOR SHARES
*-------------------------------------------------------------------------------
{ //

* append Ficus-Fare files
clear
forvalues t = 1994(1)2005 {
display `t'
append using "rawdata/ficus_fare/cleaned/ficus-fare`t'", keep(ape year va ebe wages charsoc)
}
gen labor = wages+charsoc

* factor share at sector-year level
gcollapse (sum) va ebe labor, by(ape year)
keep if ebe>0 & labor>0 & ebe+labor<.
gen share_K = ebe/(ebe+labor)
gen share_L = labor/(ebe+labor)
sum share*
sum share* [aw=ebe+labor]

* sector time-series average
gcollapse (mean) share_K share_L, by(ape)

save "output/sec_factorshare", replace

} //


*-------------------------------------------------------------------------------
* VARIABLES AT FIRM-YEAR LEVEL
*-------------------------------------------------------------------------------
{ //

* append annual ficus-fare files

clear

forvalues t = 1994(1)2007 {
display "---------     `t'      ----------"
append using "rawdata/ficus_fare/cleaned/ficus-fare`t'", keep(siren year ape emp tot_act capisoc ca va ebe resultat div stat_cj datcr)
}

forvalues t = 2008(1)2011 { // we did not extract all the variables from 2008 on
display "---------     `t'      ----------"
append using "rawdata/ficus_fare/cleaned/ficus-fare`t'", keep(siren year emp ca va ebe resultat div stat_cj datcr)
}

rename siren sir
egen firm = group(sir)
xtset firm year

* winsorize a few negative values
foreach x in emp ca tot_act div {
replace `x' = 0 if `x'<0
}

* sales
rename ca S

* value added
rename va Y

* employment
rename emp L

* past employment growth, sales growth
foreach lag in 1 3 {
gen gemp`lag' = (L-l`lag'.L)/((L+l`lag'.L)/2)
gen gsal`lag' = (S-l`lag'.S)/((S+l`lag'.S)/2)
}

* forward sales growth
gen Sf5 = f5.S
drop firm

* productivity
merge m:1 ape using "output/sec_factorshare", nogen keep(1 3)
gen tfp = log(Y) - share_L*log(L+1) - share_K*log(tot_act)
gegen tfp_secyear = mean(tfp), by(ape year)
replace tfp = tfp-tfp_secyear
drop tfp_secyear share_K share_L

* firm age
gen lengthdatcr = length(datcr)
gen y2 = 1900+real(datcr) if lengthdatcr==2
gen y4 = real(datcr) if lengthdatcr==4
replace y4 = . if y4<1800
gen y6 = real(substr(datcr,1,4)) if lengthdatcr==6
replace y6 = . if y6<1800
gen y6b = 1900+real(substr(datcr,1,2)) if lengthdatcr==6 & y6>2007
replace y6 = . if y6>2007
gen y8 = real(substr(datcr,1,4)) if lengthdatcr==8
replace y8 = . if y8<1800
gen yearcrea_ficus = .
foreach x in y2 y4 y6 y6b y8 {
	replace yearcrea_ficus = `x' if `x'<.
}
drop lengthdatcr datcr y2 y4 y6 y6b y8

* firm creation year from creation files
merge m:1 sir using "rawdata/ree_creation/cleaned/creation", keep(1 3) nogen keepusing(yearcrea)

* legal status
rename stat_cj cj

* save
save "output/firm_all_var", replace

} //


*-------------------------------------------------------------------------------
* FIRM NAMES
*-------------------------------------------------------------------------------
{ //

*** Create a file with siren numbers and company names
 
* append all ficus files
clear
gen year = .
forvalues t = 1994(1)2007 {
display "Open Ficus file for year `t'"
append using "rawdata/ficus_fare/raw/ficus`t'tab", keep(siren nom)
qui replace year = `t' if year==.
}

* drop a few missing obs
drop if inlist(siren,"","000000000") | nom==""

* drop siren that don't appear in the DADS
rename siren sir
qui merge m:1 sir using "output/dads_panel_list_of_sir", keep(3) nogen

* keep one obs per firm
gsort sir year
by sir: keep if _n==1
keep sir nom
save "output/ficus_name", replace

} //


*-------------------------------------------------------------------------------
* VARIABLES AT SECTOR-YEAR LEVEL
*-------------------------------------------------------------------------------
{ //

* append Ficus-Fare files
clear
gen year = .
forvalues t = 1994(1)2006 {
append using "rawdata/ficus_fare/cleaned/ficus-fare`t'", keep(siren capisoc tot_act tactint dep ape)
replace year = `t' if year==.
}

* remove leading and trailing 0 in departement
replace dep = substr(dep,1,2) if length(dep)==3 & substr(dep,3,1)=="0"
replace dep = substr(dep,2,3) if length(dep)==3 & substr(dep,1,1)=="0"

* sector
rename ape sec

* ict
gen ict = inlist(substr(sec,1,2),"72") | inlist(substr(sec,1,3),"300","321","322","323","332","333","642") | inlist(sec,"313Z","516G","518G","518J","713E") if sec~=""
drop if ict==.

* deal with negative capital
gen capisoc_ori = capisoc
replace capisoc = 0 if capisoc<0

* lagged capital
gegen siren_num = group(siren)
gsort siren_num year
xtset siren_num year
gen cap = capisoc if L.capisoc<.
gen capL1 = L.capisoc if capisoc<.

* growth rate of capital
foreach x in cap capL1 {
	gegen `x'_secdep = sum(`x'), by(sec dep year)
}
foreach x in cap capL1 {
	replace `x' = 0 if `x'==. // useful to calculate the leave-one-out growth rate below
}
* growth rate
gen gcap_secdep = (cap_secdep-capL1_secdep) / (0.5*(cap_secdep+capL1_secdep))
* leave-one-out growth rate
gen gcap_secdep_l1o = ((cap_secdep-cap)-(capL1_secdep-capL1)) / (0.5*((cap_secdep-cap)+(capL1_secdep-capL1)))

* save
rename siren sir
rename sec apet_sir
rename dep dept_sir
keep sir year gcap_* apet_sir dept_sir
save "output/gcap", replace

} //


*-------------------------------------------------------------------------------
* OVERPRICING
*-------------------------------------------------------------------------------
{ //

*** prepare ownership (LIFI) files to consolidate sales at the group level

forvalues t = 1994(1)2007 {
display "-----   `t'   -----"

* open yearly LIFI file
use "rawdata/lifi/raw/lifi`t'lar", clear

* keep fully owned subsidiaries
keep if txcontr>=9800

* rename variables
keep sirtg sirlifi
rename sirlifi siren

* save
duplicates drop
save "output/lifi`t'", replace

}


*** FICUS-FARE

forvalues t = 1994(1)2007 {
display "-----   `t'   -----"

* open yearly FICUS file
use siren ape ca using "rawdata/ficus_fare/cleaned/ficus-fare`t'", clear

* sales consolidated at the group level
merge 1:1 siren using "output/lifi`t'", keep(1 3) nogen
gegen cagr = sum(ca) if sirtg~="", by(sirtg)
replace cagr = ca if cagr==.

* save
keep siren ape ca cagr
save "output/sales`t'", replace
}


*** MERGE WITH STOCK PRICES

* append all
clear
gen year = .
forvalues t = 1994(1)2007 {
append using "output/sales`t'"
replace year = `t' if year==.
}

* merge with stock prices (1% listed firms not matched)
merge 1:1 siren year using "rawdata/stock_price_firm", keep(2 3) keepusing(mktcap mktcapgr return)

* lagged market cap
gsort siren year
by siren: gen mktcap_1 = mktcap[_n-1] if year[_n-1]==year-1
replace mktcap_1 = mktcap/(1+return) if mktcap_1

keep if _m==3
drop _m

save "output/firm_stock", replace

* erase temporary files
forvalues t = 1994(1)2007 {
erase "output/lifi`t'.dta"
erase "output/sales`t'.dta"
}


*** INDUSTRY-LEVEL OVERPRICING

use "output/firm_stock", clear

* price/sales in 1999
gen PS = mktcapgr/cagr if year==1999

* 1999 price run-up
gen r99 = return if year==1999

* industry equal-weighted P/S
preserve
gcollapse (mean) meanPS=PS, by(ape)
save "output/sec_stock", replace
restore

* industry value-weighted 1999 return
replace r99 = r99*mktcap_1
gen w_r99 = mktcap_1 if r99<.
gcollapse (sum) r99v=r99 w_r99, by(ape)
replace r99v = r99v/w_r99
drop w_*

* save
merge 1:1 ape using "output/sec_stock", nogen
rename ape apet
save "output/sec_stock", replace

} //


*****   SUBSIDIARIES
{

*** Construct US subsidiary dummy in each yearly file of LIFI

forvalues yr = 1997(1)2005 {

* open yearly LIFI file
use "rawdata/lifi/raw/lifi`yr'lar", clear

* bring sirtg info
joinby sirtg using "rawdata/lifi/raw/lifi`yr'tg"

* sirtg country
destring natact paystg, replace

* foreign groups
	// 1 groupe privé français
	// 2 groupe public
	// 4 groupe étranger
	// 0 entreprises du contour élargi ou de la mouvance (correspond à CONTOUR = E ou M)
	// blanc entreprises isolées

* US firms
	// paystg is country of tete de groupe
	// 404 is US
gegen usa = max(paystg==404), by(sirlifi)

* part of a business group
gegen n = sum(1), by(sirtg)
gen businessgroup = n>1
drop n

bys sirlifi: keep if _n==1
rename sirlifi sir
keep sir usa businessgroup

save "output/lifi`yr'", replace

}


*** Merge all years in 1 file

clear
gen year = .
forvalues yr = 1997(1)2005 {
append using "output/lifi`yr'"
replace year = `yr' if year==.
}
foreach x in usa businessgroup {
gegen `x'2 = max(`x'), by(sir)
drop `x'
rename `x'2 `x'
}
bys sir: keep if _n==1
save "output/lifi",replace

* erase temporary files
forvalues yr=1997(1)2005 {
erase "output/lifi`yr'.dta"
}

}
